import 'slick-carousel/slick/slick.css'
import 'slick-carousel/slick/slick-theme.css'
import { lazy, Suspense } from 'react'
const Slider = lazy(() => import('react-slick'))
import dummyVideo from '~/images/dummy-video.mp4'
import chevronRightRed from '~/images/chevron-right-red.svg'
import { NavLink } from 'react-router'
import arrowLeftGray from '~/images/arrow-left-gray.svg'
import arrowRightWhite from '~/images/arrow-right-white.svg'

function SampleNextArrow(props: any) {
  const { className, onClick } = props
  return (
    <div
      className={className}
      style={{
        transform: 'translateX(-50%)',
        left: 'calc(50% + 56px)',
        top: '112%',
        width: '56px',
        height: '56px',
        display: 'flex',
        background: '#7e2527',
        borderRadius: '50%',
        alignItems: 'center',
        justifyContent: 'center',
      }}
      onClick={onClick}
    >
      <img src={arrowRightWhite} alt="" />
    </div>
  )
}

function SamplePrevArrow(props: any) {
  const { className, onClick } = props
  return (
    <div
      className={className}
      style={{
        transform: 'translateX(-50%)',
        left: 'calc(50% - 56px)',
        top: '112%',
        width: '56px',
        height: '56px',
        display: 'flex',
        background: '#FFF',
        border: '1px solid #CED1D8',
        borderRadius: '50%',
        alignItems: 'center',
        justifyContent: 'center',
      }}
      onClick={onClick}
    >
      <img src={arrowLeftGray} alt="" />
    </div>
  )
}

export default function AppCarousel() {
  const settings = {
    dots: false,
    infinite: true,
    speed: 500,
    slidesToShow: 3,
    slidesToScroll: 1,
    nextArrow: <SampleNextArrow />,
    prevArrow: <SamplePrevArrow />,
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 2
        }
      },
      {
        breakpoint: 600,
        settings: {
          slidesToShow: 1
        }
      },
    ]
  }
  return (
    <div className="space-y-6">
      <h3 className="font-semibold text-2xl lg:text-5xl xl:text-6xl">Benim Ustam’ı Kullanmak Çok Kolay!</h3>
      <p className="text-gray lg:text-lg">
        Benim Ustam’a üye olarak sadakat programının sunduğu tüm avantajlardan
        faydalanabilirsiniz.{' '}
      </p>
      <Suspense fallback={null}>
        <div className="slider-container -mx-4 xl:-mx-6 pb-34">
          <Slider {...settings}>
            {[...Array(6)].map((_, i) => (
              <div key={i} className="space-y-6 px-4 xl:px-6">
                <div className="sm:aspect-square bg-slate-200 rounded-2xl overflow-hidden">
                  <video className="object-cover size-full" controls src={dummyVideo}></video>
                </div>
                <NavLink to="/" className="flex items-center justify-between cursor-pointer">
                  <h4 className="font-bold text-2xl">Üye Ol ve Giriş Yap</h4>
                  <img src={chevronRightRed} alt="" />
                </NavLink>
                <p className="text-lg text-gray font-medium">
                  Üyelik işlemleri sadece birkaç dakikanızı alır.
                </p>
              </div>
            ))}
          </Slider>
        </div>
      </Suspense>
    </div>
  )
}
